/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek & Leopold (2017). 
  Who becomes a Grandparent – And When? Educational Differences in the Chances 
  and Timing of Grandparenthood.
  In: Demographic Research. 
  
  Select sample by age and part of Germany. 
  
  Output file: 01_sample.dta
  
------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

set more off

// config 
run config

* load prepared data
use "${prepared}/00_prepare", clear

* 6.205 cases from the basic sample in 2008
count
assert _N==6205

/*-----------------------------------------
  Sample selection 1: 
  Remove cases who did not declared to leave either in East or West Germany 
  before reunification.
-----------------------------------------*/

drop if part==.

count
assert _N==5911

/*-----------------------------------------
  Sample selection 2: 
  Restrict to birth cohorts 1933-1948 (i.e. age 60-75 at time of interview)
-----------------------------------------*/

keep if inrange(age,60,75)

count
assert _N==2473 

/*-----------------------------------------
  Save data
-----------------------------------------*/
save "${prepared}/01_sample.dta", replace
