/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek & Leopold (2017). 
  Who becomes a Grandparent – And When? Educational Differences in the Chances 
  and Timing of Grandparenthood.
  In: Demographic Research. 
  
  PROJECT MASTER FILE
 
  The syntax of the empirical analysis is divided into different sub-files, each 
  of which completes a specific step in the analysis. 
  
  This master file runs each of these steps in the right order. 
  You can run the complete analysis by executing this file.	   
 
  Detailed documentation can be found in the respective sub-files. 
  
  Note, there is a configuration file 'config.do' that defines important 
  settings (files paths) as well as various programs needed for the analysis. 
  Before executing any other do-file this file should always run first. 

------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

set more off

// call the configuration file
run config 	

/*------------------------------------------------------------------------------
 1) Preparing the original survey data (DEAS, German Ageing Survey, 2008)
------------------------------------------------------------------------------*/

do 00_Data_Preparation.do

/*------------------------------------------------------------------------------
 2) Selecting the sample 
------------------------------------------------------------------------------*/

do 01_Sample_Selection.do

/*------------------------------------------------------------------------------
 3) Create additional variables
------------------------------------------------------------------------------*/

do 02_Additional_Variables.do

/*------------------------------------------------------------------------------
 4) Run analysis and generate tables and figures
------------------------------------------------------------------------------*/

do 03_Analysis.do

/*------------------------------------------------------------------------------
 5) Additional analyses (not shown in the paper)
------------------------------------------------------------------------------*/

// uncomment if needed
// do 04_Additional_Analyses.do

